@@ -496,14 +496,17 @@ class LogData:
 
     '''
 
-    def __init__(self, logLevel=LogLevel.INFO, debugLevel=0):
+    def __init__(self, logLevel=LogLevel.INFO, debugLevel=0,
+                 prefix=Prefix()):
         '''
         * logLevel -- The log level
         * debugLevel -- The debug level
+        * prefix -- The prefix chain to use for all loggers
 
         '''
         self.__logLevel = logLevel
         self.__debugLevel = debugLevel
+        self.__prefix = prefix
 
     def get(self, name=None, color=Colors.Foreground.White):
         '''Get a new Logger with the given name.
@@ -513,4 +516,5 @@ class LogData:
 
         '''
         return Logger(name, logLevel=self.__logLevel,
-                      debugLevel=self.__debugLevel, color=color)
+                      debugLevel=self.__debugLevel, color=color,
+                      prefix=self.__prefix)
